# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/info-circle.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Device IP Address
Network connection information

## About 
Retrieve the [IP address](https://en.wikipedia.org/wiki/IP_address), also known as the "network address" of the Device and respond verbally to the user, and if the Device supports it, display the IP address. 

## Examples 
* "What's your network address?"
* "What's your IP address?"
* "Tell me your IP address"
* "Tell me your network address"
* "What network are you connected to?"

## Credits 
Mycroft AI (@MycroftAI)

## Category
**Configuration**

## Tags
#IP-address
#IPaddress
#network-address
#network
#system
